dictknife
========================================

.. image:: https://travis-ci.org/podhmo/dictknife.svg?branch=master
  :target: https://travis-ci.org/podhmo/dictknife

swiss army knife for handling dict.

doc
----------------------------------------

http://dictknife.readthedocs.io
